#include "test.h"

int main(void)
{
	result("new test");
	return 0;
}
